==> haskell-gsasl-0.3.6-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gsasl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gsasl
version:              0.3.6
visibility:           public
id:                   gsasl-0.3.6-3QpOJ5FM19C3rIIX6IpN8d
key:                  gsasl-0.3.6-3QpOJ5FM19C3rIIX6IpN8d
license:              GPL-3.0-only
maintainer:           John Millikin <john@john-millikin.com>
author:               John Millikin <john@john-millikin.com>
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-gsasl/
synopsis:             Bindings for GNU libgsasl
category:             Network
abi:                  c2a6dffa7f5641df6e8578ac5d47ff5c
exposed:              True
exposed-modules:      Network.Protocol.SASL.GNU
import-dirs:          /usr/lib/ghc-8.8.1/site-local/gsasl-0.3.6
library-dirs:         /usr/lib/ghc-8.8.1/site-local/gsasl-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/gsasl-0.3.6
hs-libraries:         HSgsasl-0.3.6-3QpOJ5FM19C3rIIX6IpN8d
extra-libraries:      gsasl
depends:
    base-4.13.0.0 bytestring-0.10.9.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gsasl/html/gsasl.haddock
haddock-html:         /usr/share/doc/haskell-gsasl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gsasl-0.3.6-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gsasl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gsasl
version:              0.3.6
visibility:           public
id:                   gsasl-0.3.6-FWY6Ca556EcHhG0CBYasza
key:                  gsasl-0.3.6-FWY6Ca556EcHhG0CBYasza
license:              GPL-3.0-only
maintainer:           John Millikin <john@john-millikin.com>
author:               John Millikin <john@john-millikin.com>
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-gsasl/
synopsis:             Bindings for GNU libgsasl
category:             Network
abi:                  37e49a61a977003d2ef6daec1a48f476
exposed:              True
exposed-modules:      Network.Protocol.SASL.GNU
import-dirs:          /usr/lib/ghc-8.8.2/site-local/gsasl-0.3.6
library-dirs:         /usr/lib/ghc-8.8.2/site-local/gsasl-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/gsasl-0.3.6
hs-libraries:         HSgsasl-0.3.6-FWY6Ca556EcHhG0CBYasza
extra-libraries:      gsasl
depends:
    base-4.13.0.0 bytestring-0.10.10.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gsasl/html/gsasl.haddock
haddock-html:         /usr/share/doc/haskell-gsasl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
